package ex_nodecrud.view
{
	import ex_nodecrud.ApplicationFacade;
	
	import mx.collections.ArrayCollection;
	import mx.controls.Alert;
	import mx.managers.PopUpManager;
	
	import org.puremvc.as3.interfaces.IMediator;
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.patterns.mediator.Mediator;
	
	public class MainMediator extends Mediator implements IMediator
	{
		public static const NAME:String = "MainMediator";
		
		public function MainMediator(viewComponent:MainPanel)
		{
			super(NAME, viewComponent);
		}
		
		override public function listNotificationInterests():Array
		{
			return [ApplicationFacade.LOADNODES_SUCCESS,
				ApplicationFacade.OPENVIEWER,
				ApplicationFacade.CLOSEVIEWER,
				ApplicationFacade.OPENEDITOR,
				ApplicationFacade.CLOSEEDITOR,
				ApplicationFacade.CREATENODE_SUCCESS,
				ApplicationFacade.CREATENODE_FAILED,
				ApplicationFacade.UPDATENODE_SUCCESS,
				ApplicationFacade.UPDATENODE_FAILED,
				ApplicationFacade.DELETENODE_SUCCESS,
				ApplicationFacade.DELETENODE_FAILED];
		}
		
		override public function handleNotification(note:INotification):void
		{
			var nodes:ArrayCollection;
			
			switch (note.getName())
			{
				case ApplicationFacade.LOADNODES_SUCCESS:
					cView.dgdNodes.dataProvider = facade.retrieveProxy("NodesProxy").getData();
					break;
				
				// VIEWER PANEL
				case ApplicationFacade.OPENVIEWER:
					facade.registerMediator(new ViewerMediator(new ViewerPanel(), note.getBody()));
					PopUpManager.addPopUp((facade.retrieveMediator("ViewerMediator") as ViewerMediator).cView, cView);
					PopUpManager.centerPopUp((facade.retrieveMediator("ViewerMediator") as ViewerMediator).cView);
					break;
				case ApplicationFacade.CLOSEVIEWER:
					PopUpManager.removePopUp((facade.retrieveMediator("ViewerMediator") as ViewerMediator).cView);
					facade.removeMediator("ViewerMediator");
					break;
				
				// EDITOR PANEL
				case ApplicationFacade.OPENEDITOR:
					facade.registerMediator(new EditorMediator(new EditorPanel(), note.getBody()));
					PopUpManager.addPopUp((facade.retrieveMediator("EditorMediator") as EditorMediator).cView, cView);
					PopUpManager.centerPopUp((facade.retrieveMediator("EditorMediator") as EditorMediator).cView);
					break;
				case ApplicationFacade.CLOSEEDITOR:
					PopUpManager.removePopUp((facade.retrieveMediator("EditorMediator") as EditorMediator).cView);
					facade.removeMediator("EditorMediator");
					break;
				
				// ADD NODE
				case ApplicationFacade.CREATENODE_SUCCESS:
					nodes = cView.dgdNodes.dataProvider as ArrayCollection;
					nodes.addItem(note.getBody());
					sendNotification(ApplicationFacade.CLOSEEDITOR);
					break;
				case ApplicationFacade.CREATENODE_FAILED:
					Alert.show("Impossible de créer le noeud");
					break;
				
				// UPDATE NODE
				case ApplicationFacade.UPDATENODE_SUCCESS:
					nodes = cView.dgdNodes.dataProvider as ArrayCollection;
					for each(var node:Object in nodes)
					if (node.nid == note.getBody().nid)
						nodes.removeItemAt(nodes.getItemIndex(node));
					nodes.addItem(note.getBody());
					sendNotification(ApplicationFacade.CLOSEEDITOR);
					break;
				case ApplicationFacade.UPDATENODE_FAILED:
					Alert.show("Impossible de modifier le noeud");
					break;
				
				// DELETE NODE
				case ApplicationFacade.DELETENODE_SUCCESS:
					nodes = cView.dgdNodes.dataProvider as ArrayCollection;
					nodes.removeItemAt(nodes.getItemIndex(note.getBody()));
					break;
				case ApplicationFacade.DELETENODE_FAILED:
					Alert.show("Impossible de supprimer le noeud");
					break;
				
			}
		}
		
		protected function get cView():MainPanel
		{
			return viewComponent as MainPanel;
		}
	}
}
